.. Modgrammar documentation master file, created by
   sphinx-quickstart on Thu Feb 24 13:19:13 2011.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

##########################
The Modular Grammar Engine
##########################

Welcome to the documentation for the Modular Grammar Engine (modgrammar).  Modgrammar is a general-purpose library for constructing language parsers and interpreters for context-free grammar definitions using Python.

Modgrammar Resources
====================

* Python Package Index: http://pypi.python.org/pypi/modgrammar
* Project Home: http://code.google.com/p/modgrammar
* Documentation: http://code.google.com/p/modgrammar/wiki/Docs

General Documentation
=====================

.. toctree::
   :maxdepth: 2

   tutorial.rst

Library Reference
=================

.. toctree::
   :maxdepth: 2

   libref.rst

Indices and Tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

